@@ -38,6 +38,7 @@
 #include "image-loader.h"
 #include "gthumb-slide.h"
 #include "glib-utils.h"
+#include "main.h"
 
 
 static void begin_export       (CatalogPngExporter *ce);
@@ -97,7 +98,7 @@ static char *get_header_text                (CatalogPngExporter *ce,
 
 #define COL_SPACING      15
 #define ROW_SPACING      15
-#define FRAME_BORDER     8
+#define THUMB_FRAME_BORDER     8
 #define TEXT_SPACING     3
 #define CAPTION_MAX_ROWS 4
 
@@ -166,9 +167,9 @@ image_data_free (ImageData *idata)
 
 
 enum {
-	DONE,
-	PROGRESS,
-	INFO,
+	PNG_EXPORTER_DONE,
+	PNG_EXPORTER_PROGRESS,
+	PNG_EXPORTER_INFO,
 	LAST_SIGNAL
 };
 
@@ -216,6 +217,11 @@ catalog_png_exporter_finalize (GObject *object)
 		ce->file_list = NULL;
 	}
 
+	if (ce->created_list != NULL) {
+		path_list_free (ce->created_list);
+		ce->created_list = NULL;
+	}
+
 	if (ce->pages_height != NULL) {
 		g_free (ce->pages_height);
 		ce->pages_height = NULL;
@@ -274,31 +280,31 @@ catalog_png_exporter_class_init (CatalogPngExporterClass *class)
 
 	parent_class = g_type_class_peek_parent (class);
 
-	catalog_png_exporter_signals[DONE] =
-		g_signal_new ("done",
+	catalog_png_exporter_signals[PNG_EXPORTER_DONE] =
+		g_signal_new ("png_exporter_done",
 			      G_TYPE_FROM_CLASS (class),
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (CatalogPngExporterClass, done),
+			      G_STRUCT_OFFSET (CatalogPngExporterClass, png_exporter_done),
 			      NULL, NULL,
 			      gthumb_marshal_VOID__VOID,
 			      G_TYPE_NONE, 
 			      0);
 
-	catalog_png_exporter_signals[PROGRESS] =
-		g_signal_new ("progress",
+	catalog_png_exporter_signals[PNG_EXPORTER_PROGRESS] =
+		g_signal_new ("png_exporter_progress",
 			      G_TYPE_FROM_CLASS (class),
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (CatalogPngExporterClass, progress),
+			      G_STRUCT_OFFSET (CatalogPngExporterClass, png_exporter_progress),
 			      NULL, NULL,
 			      gthumb_marshal_VOID__FLOAT,
 			      G_TYPE_NONE, 
 			      1, G_TYPE_FLOAT);
 
-	catalog_png_exporter_signals[INFO] =
-		g_signal_new ("info",
+	catalog_png_exporter_signals[PNG_EXPORTER_INFO] =
+		g_signal_new ("png_exporter_info",
 			      G_TYPE_FROM_CLASS (class),
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (CatalogPngExporterClass, info),
+			      G_STRUCT_OFFSET (CatalogPngExporterClass, png_exporter_info),
 			      NULL, NULL,
 			      gthumb_marshal_VOID__STRING,
 			      G_TYPE_NONE, 
@@ -314,6 +320,7 @@ catalog_png_exporter_init (CatalogPngExporter *ce)
 	PangoFontDescription *font_desc;
 
 	ce->file_list = NULL;
+	ce->created_list = NULL;
 
 	ce->page_width = 0;
 	ce->page_height = 0;
@@ -385,7 +392,7 @@ catalog_png_exporter_init (CatalogPngExporter *ce)
 
 	ce->layout = pango_layout_new (ce->context);
 	pango_layout_set_alignment (ce->layout, PANGO_ALIGN_CENTER);
-	pango_layout_set_wrap (ce->layout, PANGO_WRAP_CHAR);
+	pango_layout_set_wrap (ce->layout, PANGO_WRAP_WORD_CHAR);
 
 	font_desc = pango_font_description_from_string (DEFAULT_FONT);
 	pango_layout_set_font_description (ce->layout, font_desc);
@@ -541,8 +548,8 @@ catalog_png_exporter_set_thumb_size (CatalogPngExporter *ce,
 	ce->thumb_width = width;
 	ce->thumb_height = height;
 
-	ce->frame_width = width + FRAME_BORDER * 2;
-	ce->frame_height = height + FRAME_BORDER * 2;
+	ce->frame_width = width + THUMB_FRAME_BORDER * 2;
+	ce->frame_height = height + THUMB_FRAME_BORDER * 2;
 }
 
 
@@ -783,17 +790,17 @@ set_item_caption (CatalogPngExporter *ce,
 
 	if ((ce->caption_fields & GTH_CAPTION_FILE_PATH) 
 	    && (ce->caption_fields & GTH_CAPTION_FILE_NAME)) {
-		char *utf8_name = g_locale_to_utf8 (idata->filename, -1, 0, 0, 0);
+		char *utf8_name = g_filename_to_utf8 (idata->filename, -1, 0, 0, 0);
 		idata->caption_row[row++] = utf8_name;
 	} else {
 		if (ce->caption_fields & GTH_CAPTION_FILE_PATH) {
 			char *path = remove_level_from_path (idata->filename);
-			char *utf8_name = g_locale_to_utf8 (path, -1, 0, 0, 0);
+			char *utf8_name = g_filename_to_utf8 (path, -1, 0, 0, 0);
 			idata->caption_row[row++] = utf8_name;
 			g_free (path);
 		} else if (ce->caption_fields & GTH_CAPTION_FILE_NAME) {
 			const char *name = file_name_from_path (idata->filename);
-			char *utf8_name = g_locale_to_utf8 (name, -1, 0, 0, 0);
+			char *utf8_name = g_filename_to_utf8 (name, -1, 0, 0, 0);
 			idata->caption_row[row++] = utf8_name;
 		}
 	}
@@ -864,7 +871,7 @@ export (CatalogPngExporter *ce)
 				g_list_free (ce->file_list);
 				ce->file_list = NULL;
 			}
-			g_signal_emit (G_OBJECT (ce), catalog_png_exporter_signals[DONE], 0);
+			g_signal_emit (G_OBJECT (ce), catalog_png_exporter_signals[PNG_EXPORTER_DONE], 0);
 			goto label_end;
 		}
  
@@ -1008,7 +1015,7 @@ export (CatalogPngExporter *ce)
 
  label_end:
 	end_export (ce);
-	g_signal_emit (G_OBJECT (ce), catalog_png_exporter_signals[DONE], 0);
+	g_signal_emit (G_OBJECT (ce), catalog_png_exporter_signals[PNG_EXPORTER_DONE], 0);
 }
 
 
@@ -1288,12 +1295,12 @@ load_next_file (CatalogPngExporter *ce)
 			g_list_free (ce->file_list);
 			ce->file_list = NULL;
 		}
-		g_signal_emit (G_OBJECT (ce), catalog_png_exporter_signals[DONE], 0);
+		g_signal_emit (G_OBJECT (ce), catalog_png_exporter_signals[PNG_EXPORTER_DONE], 0);
 		return;
 	}
 
 	g_signal_emit (G_OBJECT (ce), 
-		       catalog_png_exporter_signals[PROGRESS],
+		       catalog_png_exporter_signals[PNG_EXPORTER_PROGRESS],
 		       0,
 		       ((float) ++ce->n_images_done) / ce->n_images);
 
@@ -1323,11 +1330,11 @@ load_next_file (CatalogPngExporter *ce)
 
 	g_free (ce->info);
 
-	utf8_name = g_locale_to_utf8 (file_name_from_path (filename), -1, 0, 0, 0);
+	utf8_name = g_filename_to_utf8 (file_name_from_path (filename), -1, 0, 0, 0);
 	ce->info = g_strdup_printf (_("Loading image: %s"), utf8_name);
 	g_free (utf8_name);
 
-	g_signal_emit (G_OBJECT (ce), catalog_png_exporter_signals[INFO], 
+	g_signal_emit (G_OBJECT (ce), catalog_png_exporter_signals[PNG_EXPORTER_INFO], 
 		       0,
 		       ce->info);
 }
@@ -1394,16 +1401,21 @@ catalog_png_exporter_export (CatalogPngExporter *ce)
 	if (ce->tloader != NULL)
 		g_object_unref (G_OBJECT (ce->tloader));
 
+	if (ce->created_list != NULL) {
+		path_list_free (ce->created_list);
+		ce->created_list = NULL;
+	}
+
 	ce->tloader = THUMB_LOADER (thumb_loader_new (NULL, 
 						      ce->thumb_width,
 						      ce->thumb_height));
 	thumb_loader_use_cache (ce->tloader, FALSE);
 	g_signal_connect (G_OBJECT (ce->tloader), 
-			  "done",
+			  "thumb_done",
 			  G_CALLBACK (thumb_loader_done),
 			  ce);
 	g_signal_connect (G_OBJECT (ce->tloader), 
-			  "error",
+			  "thumb_error",
 			  G_CALLBACK (thumb_loader_error),
 			  ce);
 
@@ -1452,6 +1464,14 @@ begin_export (CatalogPngExporter *ce)
 static void
 end_export (CatalogPngExporter *ce)
 {
+	if (ce->created_list != NULL) {
+		all_windows_remove_monitor ();
+		all_windows_notify_files_created (ce->created_list);
+		all_windows_add_monitor ();
+		path_list_free (ce->created_list);
+		ce->created_list = NULL;
+	}
+
 	g_object_unref (G_OBJECT (ce->gc));
 	g_object_unref (G_OBJECT (ce->pixmap));
 }
@@ -1517,7 +1537,7 @@ begin_page (CatalogPngExporter *ce,
 	char             *utf8_name;
 
 	g_signal_emit (G_OBJECT (ce), 
-		       catalog_png_exporter_signals[PROGRESS],
+		       catalog_png_exporter_signals[PNG_EXPORTER_PROGRESS],
 		       0,
 		       ((float) page_n) / ce->pages_n);
 
@@ -1531,14 +1551,14 @@ begin_page (CatalogPngExporter *ce,
 	g_free (ce->info);
 
 	filename = _g_get_name_from_template (ce->templatev, ce->start_at + page_n - 1);
-	utf8_name = g_locale_to_utf8 (filename, -1, 0, 0, 0);
+	utf8_name = g_filename_to_utf8 (filename, -1, 0, 0, 0);
 	ce->info = g_strdup_printf (_("Creating image: %s.%s"), 
 				    utf8_name, 
 				    ce->file_type);
 	g_free (utf8_name);
 	g_free (filename);
 
-	g_signal_emit (G_OBJECT (ce), catalog_png_exporter_signals[INFO], 
+	g_signal_emit (G_OBJECT (ce), catalog_png_exporter_signals[PNG_EXPORTER_INFO], 
 		       0,
 		       ce->info);
 
@@ -1614,6 +1634,8 @@ end_page (CatalogPngExporter *ce,
 	else
 		gdk_pixbuf_save (pixbuf, path, ce->file_type, NULL, NULL);
 
+	ce->created_list = g_list_prepend (ce->created_list, g_strdup (path));
+
 	g_object_unref (pixbuf);
 	g_free (path);
 
@@ -1785,7 +1807,7 @@ paint_text (CatalogPngExporter *ce,
 		font_desc = pango_font_description_from_string (DEFAULT_FONT);
 	pango_layout_set_font_description (ce->layout, font_desc);
 
-	x += FRAME_BORDER;
+	x += THUMB_FRAME_BORDER;
 
 	pango_layout_set_text (ce->layout, utf8_text, strlen (utf8_text));
 
@@ -1845,7 +1867,7 @@ paint_comment (CatalogPngExporter *ce,
 	original_attr_list = pango_layout_get_attributes (ce->layout);
 	if (original_attr_list != NULL)
 		pango_attr_list_ref (original_attr_list);
-	x += FRAME_BORDER;
+	x += THUMB_FRAME_BORDER;
 
 	escaped_text = g_markup_escape_text (utf8_text, -1);
 	marked_text = g_strdup_printf ("<i>%s</i>", escaped_text);
